# ssb-pataka

A `secret-stack` plugin which provides:
- a graphql API for pataka
- a web-server that hosts a web-registration page

Has dependencies:
- ssb-profile
- ssb-tribes
  - this is only used for encrypting registrations sent from web-form

## Config

```js
{
  pataka: {
    allowedOrigins: [
      'some-hapu.ahau.io', // example
      'localhost:8000' // for local access if using default port
    ],
    webRegistration: {
      port: 8000,      // port form is served on
      tribes: [
        '%2Sn8sdDl5+cJqrxo2JdVACReYudCbYQAkB0sRHEZARU=.cloaked'
      ]
    }
  },
  serveBlobs: {
    hostname: 'some-hapu.ahau.io',
    port: 28088
  }
}
```

You will need to set `allowedOrigins` for your registration page to be allowed
to call your graphql API.

If `config.pataka.webRegistration.tribes` is set, then only the groupIds of tribes in
that Array will be shown as options for tribes to register for. Further, if
there is only on tribe listed, users will be automatically routed to the
registration page of that tribe.

### ENV

`AHAU_LOGGING=true` turns on verbose logging


## Development

Setup:
```bash
npm i
cd ui && npm i
```

In different terminal windows:
1. `cd ui && npm run dev` (wait for this to be ready)
2. `npm run dev` (run this is root of this project)

This will start up a pataka in development mode, and log out an invite-code.

### Developing the web-registration form

You will need to run an Āhau instance (also in development mode).

1. start up Āhau in dev-mode
2. create a group (with custom-fields)
3. join the dev Pataka you started (using invite code)
4. browse to http://localhost:8087


If you want to test the support for allowed tribes only:
1. get the `tribeId`
  - browse to tribe profile in UI
  - open dev tools > console, and run
    ```js
    decodeURIComponent(window.location.pathname.split('/')[2])
    ```
2. edit `test/test-bot.js` to add that id to `pataka.webRegistration.tribes`
3. start the testbot up
4. use the invite code to join the pataka from dev Āhau
5. browse to http://localhost:8000 (default production location we serve form)


### Testing web-registration serving

If you want to test how it will behave in a production setting, you need to
build the UI, then start a testbot in production mode:
1. `cd ui && npm run build`
2. `cd .. && node test/test-bot.js`

when not required into another file, test-bot starts up a temp instance, and if
`NODE_ENV` is not set then it will run in production mode, serving the built
files.

## Publishing

```bash
npm publish
```

Note that this auto-builds the UI before publishing (see script:
`prepublishOnly`)

